const FILE_INCLUSION_PATTERNS = [
  /\.\.\/\.\.\//, // Recorrido de directorios
  /\/etc\/passwd/, // Acceso al archivo /etc/passwd
  /\/proc\/self\/environ/, // Acceso al archivo /proc/self/environ
  /\binclude\b.*\bhttp:\/\//i, // Inclusión remota de archivos usando HTTP
  /\binclude\b.*\bftp:\/\//i, // Inclusión remota de archivos usando FTP
  /\/\w+\/\.\.\//, // Recorrido de directorios con nombres de directorios
  /\.\.\//, // Recorrido de directorios relativo
  /etc\/shadow/, // Acceso al archivo /etc/shadow
  /root\/\.ssh/, // Acceso al directorio .ssh del root
  /windows\/system32/, // Acceso al directorio system32 de Windows
  /boot.ini/, // Acceso al archivo boot.ini
  /\bfile\b:\/\/\/?/, // Inclusión de archivos locales usando el protocolo file://
  /\bphp:\/\/input\b/, // Flujo de entrada de PHP
  /\bdata\b:text\/plain;base64,/, // Datos codificados en Base64
  /expect:\/\//, // Protocolo expect
  /phar:\/\//, // Protocolo phar
  /\bini_set\b/i, // Función ini_set
  /\bopen_basedir\b/i, // Función open_basedir
  /\bload_file\b/i, // Función load_file
  /\binto\b\s+\boutfile\b/i, // Sintaxis INTO OUTFILE
  /(?:(?:[a-zA-Z]:|\/)[\w.\/\\-]+)+\.\w{2,4}/, // Rutas de archivos con extensiones
  /\bfile:\/\/\b/, // Protocolo file
  /\bphp:\/\/\b/, // Protocolo PHP
  /<\?php/i, // Etiqueta de apertura de PHP
  /data:.*?base64,/, // Datos codificados en Base64
  /expect:\/\//i, // Protocolo expect
  /phar:\/\//i, // Protocolo phar
  /\bfile_put_contents\b/i, // Función file_put_contents
  /\bexec\b/i, // Función exec
  /\bsystem\b/i, // Función system
  /\bshell_exec\b/i, // Función shell_exec
  /\bpopen\b/i, // Función popen
  /\bproc_open\b/i, // Función proc_open
];
/**
 * Detects if there is a potential file inclusion vulnerability in a given string.
 *
 * @param input - The string to analyze.
 * @returns `true` if a potential file inclusion vulnerability is detected, otherwise `false`.
 *
 * @remarks
 * This function uses a series of regular expressions to look for common file inclusion patterns in the input string.
 * Patterns include directory traversal, remote file inclusion, and access to sensitive files and directories.
 *
 * @example
 * ```typescript
 * const input = "../../etc/passwd";
 * const isFileInclusion = detectFileInclusion(input);
 * console.log(isFileInclusion); // Output: true
 * ```
 *
 * @autor Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
export function detectFileInclusion(input: string): boolean {
  return FILE_INCLUSION_PATTERNS.some((pattern) => pattern.test(input));
}
